==> mozc-2.32.5994.102.tar.gz: mozc-2.32.5994.102/src/gui/base/msime_user_dictionary_importer.h <==
// Copyright 2010-2021, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_GUI_BASE_MSIME_USER_DICTIONARY_IMPORTER_H_
#define MOZC_GUI_BASE_MSIME_USER_DICTIONARY_IMPORTER_H_

#include "dictionary/user_dictionary_importer.h"

namespace mozc {
namespace gui {

class MSIMEUserDictionarImporter {
 public:
  MSIMEUserDictionarImporter() = delete;
  MSIMEUserDictionarImporter(const MSIMEUserDictionarImporter&) = delete;
  MSIMEUserDictionarImporter& operator=(const MSIMEUserDictionarImporter&) =
      delete;
  // Caller must take the ownership.
  // Only available on Windows.
  static UserDictionaryImporter::InputIteratorInterface *Create();
};

}  // namespace gui
}  // namespace mozc

#endif  // MOZC_GUI_BASE_MSIME_USER_DICTIONARY_IMPORTER_H_

==> mozc-3.33.6089.tar.gz: mozc-3.33.6089/src/gui/base/msime_user_dictionary_importer.h <==
// Copyright 2010-2021, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_GUI_BASE_MSIME_USER_DICTIONARY_IMPORTER_H_
#define MOZC_GUI_BASE_MSIME_USER_DICTIONARY_IMPORTER_H_

#include "dictionary/user_dictionary_importer.h"

namespace mozc {
namespace gui {

class MSIMEUserDictionarImporter {
 public:
  MSIMEUserDictionarImporter() = delete;
  MSIMEUserDictionarImporter(const MSIMEUserDictionarImporter&) = delete;
  MSIMEUserDictionarImporter& operator=(const MSIMEUserDictionarImporter&) =
      delete;
  // Caller must take the ownership.
  // Only available on Windows.
  static user_dictionary::InputIteratorInterface* Create();
};

}  // namespace gui
}  // namespace mozc

#endif  // MOZC_GUI_BASE_MSIME_USER_DICTIONARY_IMPORTER_H_
